@@ -9,7 +9,7 @@
 #'   'Details' for explanation. Allowed types include: \itemize{ \item
 #'   \code{numeric} for numeric and binary characters, \item \code{ord.num} for
 #'   ordered numeric characters, \item \code{ord.fac} for ordered factor
-#'   characters, or \item \code{ord.factor} for factor characters. }
+#'   characters, or \item \code{factor} for factor characters. }
 #' @param char.names Optional character string listing character names.
 #' @param state.names Optional character string listing character state names.
 #' @param constraint Positive integer specifying the maximum number of "multiple
@@ -33,7 +33,7 @@
 #'   characters describe diet and foraging habit, mobility, microhabitat, among
 #'   others, with the individual diets, modes of locomotions, and microhabitats
 #'   as possible character states.  When any combination of character states is
-#'   allowed, the framework serves as a theoretical ecospace; actually occuring
+#'   allowed, the framework serves as a theoretical ecospace; actually occurring
 #'   life-habit combinations circumscribe the realized ecospace.
 #'
 #'   Arguments \code{nchar, char.state, char.type} specify the number and types
@@ -52,20 +52,20 @@
 #'   characters (factors with a specified order). An example is mobility:
 #'   habitual > intermittent > facultative > passive > sedentary. (If wish to
 #'   specify relative distances between these ordered factors, it is best to use
-#'   an ordered numeric character type instead). \item \code{ord.factor} for
+#'   an ordered numeric character type instead). \item \code{factor} for
 #'   discrete, unordered factors (e.g., diet can have states of autotrophic,
 #'   carnivorous, herbivorous, or microbivorous).}
 #'
 #'   Binary characters can be treated individually (e.g., states of
-#'   present=1/absent=0) or can be treated as multiple binary character states.
+#'   present = 1/absent = 0) or can be treated as multiple binary character states.
 #'   For example, the character 'reproduction' could be treated as including two
 #'   states [sexual, asexual] with exclusively sexual habits coded as [0,1],
 #'   exclusively asexual as [1,0], and hermaphrodites as [1,1]. The
 #'   \code{constraint} argument allows additional control of such combinations.
-#'   Setting \code{constraint=2} only allows a maximum of "two-presence"
+#'   Setting \code{constraint = 2} only allows a maximum of "two-presence"
 #'   combinations (e.g., [1,0,0], [0,1,0], [0,0,1], [1,1,0], [1,0,1], and
 #'   [0,1,1]) as state combinations, but excludes [1,1,1]; setting
-#'   \code{constraint=1} only allows the first three of these combinations; the
+#'   \code{constraint = 1} only allows the first three of these combinations; the
 #'   default behavior (\code{Inf}) allows all of these combinations. In all
 #'   cases, the nonsensical "all-absence" state combination [0,0,0] is
 #'   disallowed.
@@ -95,7 +95,7 @@
 #'   character, plus a final list component recording constraints used in
 #'   producing allowable character states.
 #'
-#'   Each character conponent has the following list components:\describe{
+#'   Each character component has the following list components:\describe{
 #'   \item{\code{char}}{character name.}\item{\code{type}}{character type.}
 #'   \item{\code{char.space}}{data frame listing each allowable state
 #'   combination in each row, the calculated proportional weight (\code{pro}),
@@ -114,7 +114,7 @@
 #'   also excludes taxonomic identifiers (class, genus, species).}}
 #'
 #' @note If you have trouble matching the characters with \code{char.state} and
-#'   \code{char.type,}, see \code{data.frame} in first example for easy way to
+#'   \code{char.type}, see \code{data.frame} in first example for easy way to
 #'   trouble-shoot. If you have trouble supplying correct length of
 #'   \code{char.name, state.name} and \code{weight.file}, consider producing an
 #'   ecospace framework with defaults first, then using these to supply custom
@@ -163,8 +163,8 @@
 #' char.type <- replace(char.type, char.state == 5, "ord.fac")
 #' char.type <- replace(char.type, char.state > 5, "factor")
 #' # Good practice to confirm everything matches expectations:
-#' data.frame(char=seq(nchar), char.state, char.type)
-#' ecospace <- create_ecospace(nchar, char.state, char.type, constraint=Inf)
+#' data.frame(char = seq(nchar), char.state, char.type)
+#' ecospace <- create_ecospace(nchar, char.state, char.type, constraint = Inf)
 #' ecospace
 #'
 #' # How many life habits in this ecospace are theoretically possible?
@@ -173,18 +173,18 @@
 #' # ~12 million
 #'
 #' # Observe effect of constraint for binary characters
-#' create_ecospace(1, 4, "numeric", constraint=Inf)[[1]]$char.space
-#' create_ecospace(1, 4, "numeric", constraint=2)[[1]]$char.space
-#' create_ecospace(1, 4, "numeric", constraint=1)[[1]]$char.space
-#' try(create_ecospace(1, 4, "numeric", constraint=1.5)[[1]]$char.space) # ERROR!
-#' try(create_ecospace(1, 4, "numeric", constraint=0)[[1]]$char.space) # ERROR!
+#' create_ecospace(1, 4, "numeric", constraint = Inf)[[1]]$char.space
+#' create_ecospace(1, 4, "numeric", constraint = 2)[[1]]$char.space
+#' create_ecospace(1, 4, "numeric", constraint = 1)[[1]]$char.space
+#' try(create_ecospace(1, 4, "numeric", constraint = 1.5)[[1]]$char.space) # ERROR!
+#' try(create_ecospace(1, 4, "numeric", constraint = 0)[[1]]$char.space) # ERROR!
 #'
 #' # Using custom-weighting for traits (singletons weighted twice as frequent
 #' #   as other state combinations)
 #' weight.file <- c(rep(2, 3), rep(1, 3), 2, 2, 1, rep(1, 4), rep(2, 3), rep(1, 3),
 #' rep(1, 14), 2, 2, 1, rep(1, 4), rep(2, 3), rep(1, 3), rep(1, 5))
-#' create_ecospace(nchar, char.state, char.type, constraint=2,
-#'   weight.file=weight.file)
+#' create_ecospace(nchar, char.state, char.type, constraint = 2,
+#'   weight.file = weight.file)
 #'
 #' # Bambach's (1983, 1985) classic ecospace framework
 #' # 3 characters, all factors with variable states
@@ -240,21 +240,22 @@
 #'   "AREL", "IREL", "FAAB", "FIAB", "FAST", "FARL", "FIRL", "FRST", "AMBT", "FILT",
 #'   "ATTF", "MASS", "RAPT", "AUTO", "MICR", "CARN", "INCP", "PART", "BULK")
 #' ecospace <- create_ecospace(nchar, char.state, char.type, char.names, state.names,
-#'   constraint=2, weight.file=KWTraits)
+#'   constraint = 2, weight.file = KWTraits)
 #' ecospace
 #' seq <- seq(nchar)
 #' prod(sapply(seq, function(seq) length(ecospace[[seq]]$allowed.combos)))
 #' # ~57 billion life habits
 #'
 #' ecospace <- create_ecospace(nchar, char.state, char.type, char.names, state.names,
-#'   constraint=Inf)
+#'   constraint = Inf)
 #' ecospace
 #' seq <- seq(nchar)
 #' prod(sapply(seq, function(seq) length(ecospace[[seq]]$allowed.combos)))
 #' # ~3.6 trillion life habits
 #'
 #' @export
-create_ecospace <- function(nchar, char.state, char.type, char.names=NA, state.names=NA, constraint=Inf, weight.file=NA) {
+create_ecospace <- function(nchar, char.state, char.type, char.names = NA,
+                            state.names = NA, constraint = Inf, weight.file = NA) {
   if (is.finite(constraint) &
       (constraint < 1 |
        (abs(constraint - round(constraint)) > .Machine$double.eps)))
